pub struct TimeoutHandle { /* private fields */ }Expand description
A handle to a pending timeout.
A handle to a running timeout triggered with UseTimeout::action.
This handle allows you to cancel the timeout from triggering with TimeoutHandle::cancel
See use_timeout for more information.
Implementations
Sourceimpl TimeoutHandle
impl TimeoutHandle